@@ -5,9 +5,12 @@ import logging
 import functools
 import time
 import collections
+import calendar
 from io import BytesIO
 from datetime import datetime, timedelta
 
+import pytz
+
 from dateutil.parser import parser
 dateparser = parser()
 
@@ -23,6 +26,7 @@ try:
 except:
     unicode = str
 
+
 class Client(object):
     """
     Main client class for interacting with the exposed Strava v3 API methods.
@@ -48,6 +52,10 @@ class Client(object):
                              :class:`stravalib.util.limiter.DefaultRateLimiter' will
                              be used.
         :type rate_limiter: callable
+
+        :param requests_session: (Optional) pass request session object.
+        :type requests_session: requests.Session() object
+
         """
         self.log = logging.getLogger('{0.__module__}.{0.__name__}'.format(self.__class__))
 
@@ -75,7 +83,8 @@ class Client(object):
         """
         self.protocol.access_token = v
 
-    def authorization_url(self, client_id, redirect_uri, approval_prompt='auto', scope=None, state=None):
+    def authorization_url(self, client_id, redirect_uri, approval_prompt='auto',
+                          scope=None, state=None):
         """
         Get the URL needed to authorize your application to access a Strava user's information.
 
@@ -118,12 +127,28 @@ class Client(object):
         :type code: str
 
         :return: The access token.
-        :rtype: str
+        :rtype: :py:class:`str`
         """
         return self.protocol.exchange_code_for_token(client_id=client_id,
                                                      client_secret=client_secret,
                                                      code=code)
 
+    def _utc_datetime_to_epoch(self, activity_datetime):
+        """
+        Convert the specified datetime value to a unix epoch timestamp (seconds since epoch).
+
+        :param activity_datetime: A string which may contain tzinfo (offset) or a datetime object (naive datetime will
+                                    be considered to be UTC).
+        :return: Epoch timestamp.
+        :rtype: int
+        """
+        if isinstance(activity_datetime, str):
+            activity_datetime = dateparser.parse(activity_datetime)
+        assert isinstance(activity_datetime, datetime)
+        if activity_datetime.tzinfo:
+            activity_datetime = activity_datetime.astimezone(pytz.utc)
+
+        return calendar.timegm(activity_datetime.timetuple())
 
     def get_activities(self, before=None, after=None, limit=None):
         """
@@ -142,17 +167,16 @@ class Client(object):
 
         :param limit: How many maximum activities to return.
         :type limit: int
+
+        :return: An iterator of :class:`stravalib.model.Activity` objects.
+        :rtype: :class:`BatchedResultsIterator`
         """
 
         if before:
-            if isinstance(before, str):
-                before = dateparser.parse(before, ignoretz=True)
-            before = time.mktime(before.timetuple())
+            before = self._utc_datetime_to_epoch(before)
 
         if after:
-            if isinstance(after, str):
-                after = dateparser.parse(after, ignoretz=True)
-            after = time.mktime(after.timetuple())
+            after = self._utc_datetime_to_epoch(after)
 
         params = dict(before=before, after=after)
         result_fetcher = functools.partial(self.protocol.get,
@@ -164,7 +188,6 @@ class Client(object):
                                       result_fetcher=result_fetcher,
                                       limit=limit)
 
-
     def get_athlete(self, athlete_id=None):
         """
         Gets the specified athlete; if athlete_id is None then retrieves a
@@ -177,6 +200,7 @@ class Client(object):
 
         :param: athlete_id: The numeric ID of the athlete to fetch.
         :type: athlete_id: int
+
         :return: The athlete model object.
         :rtype: :class:`stravalib.model.Athlete`
         """
@@ -193,10 +217,12 @@ class Client(object):
 
         http://strava.github.io/api/v3/follow/#friends
 
-        :param athlete_id
-        :type athlete_id: int
+        :param: athlete_id
+        :type: athlete_id: int
+
         :param limit: Maximum number of athletes to return (default unlimited).
         :type limit: int
+
         :return: An iterator of :class:`stravalib.model.Athlete` objects.
         :rtype: :class:`BatchedResultsIterator`
         """
@@ -218,10 +244,12 @@ class Client(object):
 
         http://strava.github.io/api/v3/follow/#followers
 
-        :param athlete_id
+        :param: athlete_id
         :type athlete_id: int
+
         :param limit: Maximum number of athletes to return (default unlimited).
         :type limit: int
+
         :return: An iterator of :class:`stravalib.model.Athlete` objects.
         :rtype: :class:`BatchedResultsIterator`
         """
@@ -246,8 +274,10 @@ class Client(object):
 
         :param athlete_id: The ID of the other athlete (for follower intersection with current athlete)
         :type athlete_id: int
+
         :param limit: Maximum number of athletes to return. (default unlimited)
         :type limit: int
+
         :return: An iterator of :class:`stravalib.model.Athlete` objects.
         :rtype: :class:`BatchedResultsIterator`
         """
@@ -260,6 +290,31 @@ class Client(object):
                                       result_fetcher=result_fetcher,
                                       limit=limit)
 
+    def get_athlete_koms(self, athlete_id, limit=None):
+        """
+        Gets Q/KOMs/CRs for specified athlete.
+
+        KOMs are returned as `stravalib.model.SegmentEffort` objects.
+
+        http://strava.github.io/api/v3/athlete/#koms
+
+        :param athlete_id: The ID of the athlete.
+        :type athlete_id: int
+
+        :param limit: Maximum number of KOM segment efforts to return (default unlimited).
+        :type limit: int
+
+        :return: An iterator of :class:`stravalib.model.SegmentEffort` objects.
+        :rtype: :class:`BatchedResultsIterator`
+        """
+        result_fetcher = functools.partial(self.protocol.get,
+                                           '/athletes/{id}/koms',
+                                           id=athlete_id)
+
+        return BatchedResultsIterator(entity=model.SegmentEffort,
+                                      bind_client=self,
+                                      result_fetcher=result_fetcher,
+                                      limit=limit)
 
     def get_athlete_clubs(self):
         """
@@ -267,11 +322,32 @@ class Client(object):
 
         http://strava.github.io/api/v3/clubs/#get-athletes
 
-        :rtype: list of :class:`stravalib.model.Club`
+        :return: A list of :class:`stravalib.model.Club`
+        :rtype: :py:class:`list`
         """
         club_structs = self.protocol.get('/athlete/clubs')
         return [model.Club.deserialize(raw, bind_client=self) for raw in club_structs]
 
+    def join_club(self, club_id):
+        """
+        Joins the club on behalf of authenticated athlete.
+
+        (Access token with write permissions required.)
+
+        :param club_id: The numeric ID of the club to join.
+        """
+        self.protocol.post('clubs/{id}/join', id=club_id)
+
+    def leave_club(self, club_id):
+        """
+        Leave club on behalf of authenticated user.
+
+        (Acces token with write permissions required.)
+
+        :param club_id:
+        """
+        self.protocol.post('clubs/{id}/leave', id=club_id)
+
     def get_club(self, club_id):
         """
         Return a specific club object.
@@ -279,6 +355,8 @@ class Client(object):
         http://strava.github.io/api/v3/clubs/#get-details
 
         :param club_id: The ID of the club to fetch.
+        :type club_id: int
+
         :rtype: :class:`stravalib.model.Club`
         """
         raw = self.protocol.get("/clubs/{id}", id=club_id)
@@ -291,8 +369,11 @@ class Client(object):
         http://strava.github.io/api/v3/clubs/#get-members
 
         :param club_id: The numeric ID for the club.
+        :type club_id: int
+
         :param limit: Maximum number of athletes to return. (default unlimited)
         :type limit: int
+
         :return: An iterator of :class:`stravalib.model.Athlete` objects.
         :rtype: :class:`BatchedResultsIterator`
         """
@@ -310,8 +391,11 @@ class Client(object):
         http://strava.github.io/api/v3/clubs/#get-activities
 
         :param club_id: The numeric ID for the club.
+        :type club_id: int
+
         :param limit: Maximum number of activities to return. (default unlimited)
         :type limit: int
+
         :return: An iterator of :class:`stravalib.model.Activity` objects.
         :rtype: :class:`BatchedResultsIterator`
         """
@@ -322,7 +406,6 @@ class Client(object):
         return BatchedResultsIterator(entity=model.Activity, bind_client=self,
                                       result_fetcher=result_fetcher, limit=limit)
 
-
     def get_activity(self, activity_id):
         """
         Gets specified activity.
@@ -332,6 +415,8 @@ class Client(object):
         http://strava.github.io/api/v3/activities/#get-details
 
         :param activity_id: The ID of activity to fetch.
+        :type activity_id: int
+
         :rtype: :class:`stravalib.model.Activity`
         """
         raw = self.protocol.get('/activities/{id}', id=activity_id)
@@ -345,6 +430,7 @@ class Client(object):
 
         :param limit: Maximum number of activities to return. (default unlimited)
         :type limit: int
+
         :return: An iterator of :class:`stravalib.model.Activity` objects.
         :rtype: :class:`BatchedResultsIterator`
         """
@@ -353,8 +439,8 @@ class Client(object):
         return BatchedResultsIterator(entity=model.Activity, bind_client=self,
                                       result_fetcher=result_fetcher, limit=limit)
 
-
-    def create_activity(self, name, activity_type, start_date_local, elapsed_time, description=None, distance=None):
+    def create_activity(self, name, activity_type, start_date_local, elapsed_time,
+                        description=None, distance=None):
         """
         Create a new manual activity.
 
@@ -362,16 +448,23 @@ class Client(object):
         :meth:`stravalib.client.Client.upload_activity` method instead.
 
         :param name: The name of the activity.
+        :type name: str
+
         :param activity_type: The activity type (case-insensitive).
                               Possible values: ride, run, swim, workout, hike, walk, nordicski,
                               alpineski, backcountryski, iceskate, inlineskate, kitesurf, rollerski,
                               windsurf, workout, snowboard, snowshoe
-        :param start_date: Local date/time of activity start. (TZ info will be ignored)
-        :type start_date: :class:`datetime.datetime` or string in ISO8601 format.
+        :type activity_type: str
+
+        :param start_date_local: Local date/time of activity start. (TZ info will be ignored)
+        :type start_date_local: :class:`datetime.datetime` or string in ISO8601 format.
+
         :param elapsed_time: The time in seconds or a :class:`datetime.timedelta` object.
         :type elapsed_time: :class:`datetime.timedelta` or int (seconds)
+
         :param description: The description for the activity.
         :type description: str
+
         :param distance: The distance in meters (float) or a :class:`units.quantity.Quantity` instance.
         :type distance: :class:`units.quantity.Quantity` or float (meters)
         """
@@ -409,6 +502,8 @@ class Client(object):
         http://strava.github.io/api/v3/activities/#put-updates
 
         :param activity_id: The ID of the activity to update.
+        :type activity_id: int
+
         :param name: The name of the activity.
         :param activity_type: The activity type (case-insensitive).
                               Possible values: ride, run, swim, workout, hike,
@@ -420,6 +515,7 @@ class Client(object):
         :param trainer: Whether this is a trainer activity.
         :param gear_id: Alpha-numeric ID of gear (bike, shoes) used on this activity.
         :param description: Description for the activity.
+
         :return: The updated activity.
         :rtype: :class:`stravalib.model.Activity`
         """
@@ -511,6 +607,12 @@ class Client(object):
         Requires premium account.
 
         http://strava.github.io/api/v3/activities/#zones
+
+        :param activity_id: The activity for which to zones.
+        :type activity_id: int
+
+        :return: An list of :class:`stravalib.model.ActivityComment` objects.
+        :rtype: :py:class:`list`
         """
         zones = self.protocol.get('/activities/{id}/zones', id=activity_id)
         # We use a factory to give us the correct zone based on type.
@@ -523,9 +625,14 @@ class Client(object):
         http://strava.github.io/api/v3/comments/#list
 
         :param activity_id: The activity for which to fetch comments.
+        :type activity_id: int
+
         :param markdown: Whether to include markdown in comments (default is false/filterout).
+        :type markdown: bool
+
         :param limit: Max rows to return (default unlimited).
         :type limit: int
+
         :return: An iterator of :class:`stravalib.model.ActivityComment` objects.
         :rtype: :class:`BatchedResultsIterator`
         """
@@ -544,9 +651,12 @@ class Client(object):
         http://strava.github.io/api/v3/kudos/#list
 
         :param activity_id: The activity for which to fetch kudos.
+        :type activity_id: int
+
         :param limit: Max rows to return (default unlimited).
         :type limit: int
-        :return: An iterator of :class:`stravalib.model.Athlete` objects.
+
+        :return: An iterator of :class:`stravalib.model.ActivityKudos` objects.
         :rtype: :class:`BatchedResultsIterator`
         """
         result_fetcher = functools.partial(self.protocol.get,
@@ -565,6 +675,8 @@ class Client(object):
         http://strava.github.io/api/v3/photos/
 
         :param activity_id: The activity for which to fetch kudos.
+        :type activity_id: int
+
         :return: An iterator of :class:`stravalib.model.ActivityPhoto` objects.
         :rtype: :class:`BatchedResultsIterator`
         """
@@ -576,7 +688,6 @@ class Client(object):
                                       bind_client=self,
                                       result_fetcher=result_fetcher)
 
-
     def get_activity_laps(self, activity_id):
         """
         Gets the laps from an activity.
@@ -584,6 +695,8 @@ class Client(object):
         http://strava.github.io/api/v3/activities/#laps
 
         :param activity_id: The activity for which to fetch laps.
+        :type activity_id: int
+
         :return: An iterator of :class:`stravalib.model.ActivityLaps` objects.
         :rtype: :class:`BatchedResultsIterator`
         """
@@ -594,6 +707,27 @@ class Client(object):
         return BatchedResultsIterator(entity=model.ActivityLap,
                                       bind_client=self,
                                       result_fetcher=result_fetcher)
+        
+    def get_related_activities(self, activity_id, limit=None):
+        """
+        Returns the activities that were matched as 'with this activity'.
+
+        http://strava.github.io/api/v3/activities/#get-related
+
+        :param activity_id: The activity for which to fetch related activities.
+        :type activity_id: int
+
+        :return: An iterator of :class:`stravalib.model.Activity` objects.
+        :rtype: :class:`BatchedResultsIterator`
+        """
+        result_fetcher = functools.partial(self.protocol.get,
+                                           '/activities/{id}/related',
+                                           id=activity_id)
+
+        return BatchedResultsIterator(entity=model.Activity,
+                                      bind_client=self,
+                                      result_fetcher=result_fetcher,
+                                      limit=limit)
 
     def get_gear(self, gear_id):
         """
@@ -603,6 +737,7 @@ class Client(object):
 
         :param gear_id: The gear id.
         :type gear_id: str
+
         :return: The Bike or Shoe subclass object.
         :rtype: :class:`stravalib.model.Gear`
         """
@@ -615,6 +750,9 @@ class Client(object):
         http://strava.github.io/api/v3/efforts/#retrieve
 
         :param effort_id: The id of associated effort to fetch.
+        :type effort_id: int
+
+        :return: The specified effort on a segment.
         :rtype: :class:`stravalib.model.SegmentEffort`
         """
         return model.SegmentEffort.deserialize(self.protocol.get('/segment_efforts/{id}',
@@ -627,12 +765,14 @@ class Client(object):
         http://strava.github.io/api/v3/segments/#retrieve
 
         :param segment_id: The segment to fetch.
+        :type segment_id: int
+
+        :return: A segment object.
         :rtype: :class:`stravalib.model.Segment`
         """
         return model.Segment.deserialize(self.protocol.get('/segments/{id}',
                                          id=segment_id), bind_client=self)
 
-
     def get_starred_segment(self, limit=None):
         """
         Returns a summary representation of the segments starred by the
@@ -643,7 +783,8 @@ class Client(object):
         :param limit: (optional), limit number of starred segments returned.
         :type limit: int
 
-        :rtype: :class:`stravalib.model.Segment`
+        :return: An iterator of :class:`stravalib.model.Segment` starred by authenticated user.
+        :rtype: :class:`BatchedResultsIterator`
         """
 
         params = {}
@@ -658,30 +799,52 @@ class Client(object):
                                       result_fetcher=result_fetcher,
                                       limit=limit)
 
-
     def get_segment_leaderboard(self, segment_id, gender=None, age_group=None, weight_class=None,
-                                following=None, club_id=None, timeframe=None, top_results_limit=None):
+                                following=None, club_id=None, timeframe=None, top_results_limit=None,
+                                page=None):
         """
         Gets the leaderboard for a segment.
 
         http://strava.github.io/api/v3/segments/#leaderboard
 
-        Note that by default Strava will return the top 10 results *and then will also include
-        the bottom 5 results*.  The top X results can be configured by setting the top_results_limit
-        parameter; however,the bottom 5 results are always included.  (i.e. if you specify top_results_limit=15,
-        you will get a total of 20 entries back.)
+        Note that by default Strava will return the top 10 results, and if the current user has ridden
+        that segment, the current user's result along with the two results above in rank and the two
+        results below will be included.  The top X results can be configured by setting the top_results_limit
+        parameter; however, the other 5 results will be included if the current user has ridden that segment.
+        (i.e. if you specify top_results_limit=15, you will get a total of 20 entries back.)
 
         :param segment_id: ID of the segment.
+        :type segment_id: int
+
         :param gender: (optional) 'M' or 'F'
+        :type gender: str
+
         :param age_group: (optional) '0_24', '25_34', '35_44', '45_54', '55_64', '65_plus'
+        :type age_group: str
+
         :param weight_class: (optional) pounds '0_124', '125_149', '150_164', '165_179', '180_199', '200_plus'
                              or kilograms '0_54', '55_64', '65_74', '75_84', '85_94', '95_plus'
+        :type weight_class: str
+
         :param following: (optional) Limit to athletes current user is following.
+        :type following: bool
+
         :param club_id: (optional) limit to specific club
+        :type club_id: int
+
         :param timeframe: (optional)  'this_year', 'this_month', 'this_week', 'today'
+        :type timeframe: str
+
         :param top_results_limit: (optional, strava default is 10 + 5 from end) How many of leading leaderboard entries to display.
                             See description for why this is a little confusing.
+        :type top_results_limit: int
+
+        :param page: (optional, strava default is 1) Page number of leaderboard to return, sorted by highest ranking leaders
+        :type page: int
+
+        :return: The SegmentLeaderboard for the specified page (default: 1)
         :rtype: :class:`stravalib.model.SegmentLeaderboard`
+
         """
         params = {}
         if gender is not None:
@@ -717,6 +880,9 @@ class Client(object):
         if top_results_limit is not None:
             params['per_page'] = top_results_limit
 
+        if page is not None:
+            params['page'] = page
+
         return model.SegmentLeaderboard.deserialize(self.protocol.get('/segments/{id}/leaderboard',
                                                                       id=segment_id,
                                                                       **params),
@@ -724,7 +890,7 @@ class Client(object):
 
     def get_segment_efforts(self, segment_id, athlete_id=None,
                             start_date_local=None, end_date_local=None,
-                            limit=None ):
+                            limit=None):
         """
         Gets all efforts on a particular segment sorted by start_date_local
 
@@ -746,9 +912,9 @@ class Client(object):
         http://strava.github.io/api/v3/segments/#all_efforts
 
         :param segment_id: ID of the segment.
-        :type segment_id: int
+        :type segment_id: param
 
-        :param athlete_id: (optional) ID of athlete.
+        :int athlete_id: (optional) ID of athlete.
         :type athlete_id: int
 
         :param start_date_local: (optional) efforts before this date will be excluded.
@@ -759,10 +925,11 @@ class Client(object):
                                            Either as ISO8601 or datetime object
         :type end_date_local: datetime.datetime or str
 
-        :param top_results_limit: (optional),
+        :param top_results_limit: (optional), limit number of efforts.
         :type results_limit: int
 
-        :rtype: :class:`stravalib.model.SegmentEffort`
+        :return: An iterator of :class:`stravalib.model.SegmentEffort` efforts on a segment.
+        :rtype: :class:`BatchedResultsIterator`
 
         """
         params = {"segment_id": segment_id}
@@ -798,12 +965,19 @@ class Client(object):
 
         :param bounds: list of bounding box corners lat/lon [sw.lat, sw.lng, ne.lat, ne.lng] (south,west,north,east)
         :type bounds: list of 4 floats or list of 2 (lat,lon) tuples
+
         :param activity_type: (optional, default is riding)  'running' or 'riding'
         :type activity_type: str
+
         :param min_cat: (optional) Minimum climb category filter
         :type min_cat: int
+
         :param max_cat: (optional) Maximum climb category filter
         :type max_cat: int
+
+        :return: An list of :class:`stravalib.model.Segment`.
+        :rtype: :py:class:`list`
+
         """
         if len(bounds) == 2:
             bounds = (bounds[0][0], bounds[0][1], bounds[1][0], bounds[1][2])
@@ -825,14 +999,15 @@ class Client(object):
 
         raw = self.protocol.get('/segments/explore', **params)
         return [model.SegmentExplorerResult.deserialize(v, bind_client=self)
-                                                    for v in raw['segments']]
-
+                for v in raw['segments']]
 
     def get_activity_streams(self, activity_id, types=None,
                              resolution=None, series_type=None):
         """
         Returns an streams for an activity.
 
+        http://strava.github.io/api/v3/streams/#activity
+
         Streams represent the raw data of the uploaded file. External
         applications may only access this information for activities owned
         by the authenticated athlete.
@@ -847,24 +1022,30 @@ class Client(object):
         http://strava.github.io/api/v3/streams/#activity
 
         :param activity_id: The ID of activity.
-        :type: int
+        :type activity_id: int
+
         :param types: (optional) A list of the the types of streams to fetch.
         :type types: list
+
         :param resolution: (optional, default is 'all') indicates desired number
                             of data points. 'low' (100), 'medium' (1000),
                             'high' (10000) or 'all'.
         :type resolution: str
+
         :param series_type: (optional, default is 'distance'.  Relevant only if
                              using resolution either 'time' or 'distance'.
                              Used to index the streams if the stream is being
                              reduced.
         :type series_type: str
-        :rtype: :class:`stravalib.model.Stream`
+
+        :return: An dictionary of :class:`stravalib.model.Stream` from the activity.
+        :rtype: :py:class:`dict`
+
         """
 
         # stream are comma seperated list
         if types is not None:
-            types= ",".join(types)
+            types = ",".join(types)
 
         params = {}
         if resolution is not None:
@@ -873,26 +1054,24 @@ class Client(object):
         if series_type is not None:
             params["series_type"] = series_type
 
-        result_fetcher = functools.partial(
-                              self.protocol.get,
-                              '/activities/{id}/streams/{types}'.format(
-                                                                id=activity_id,
-                                                                types=types),
-                                                                **params)
+        result_fetcher = functools.partial(self.protocol.get,
+                                           '/activities/{id}/streams/{types}'.format(id=activity_id, types=types),
+                                           **params)
 
         streams = BatchedResultsIterator(entity=model.Stream,
                                          bind_client=self,
                                          result_fetcher=result_fetcher)
 
         # Pack streams into dictionary
-        return {i.type : i for i in streams}
+        return {i.type: i for i in streams}
 
-
-    def get_effort_streams(self, effort_id, types=None,
-                           resolution=None, series_type=None):
+    def get_effort_streams(self, effort_id, types=None, resolution=None,
+                           series_type=None):
         """
         Returns an streams for an effort.
 
+        http://strava.github.io/api/v3/streams/#effort
+
         Streams represent the raw data of the uploaded file. External
         applications may only access this information for activities owned
         by the authenticated athlete.
@@ -907,24 +1086,30 @@ class Client(object):
         http://strava.github.io/api/v3/streams/#effort
 
         :param effort_id: The ID of effort.
-        :type: int
+        :type effort_id: int
+
         :param types: (optional) A list of the the types of streams to fetch.
         :type types: list
+
         :param resolution: (optional, default is 'all') indicates desired number
                             of data points. 'low' (100), 'medium' (1000),
                             'high' (10000) or 'all'.
         :type resolution: str
+
         :param series_type: (optional, default is 'distance'.  Relevant only if
                              using resolution either 'time' or 'distance'.
                              Used to index the streams if the stream is being
                              reduced.
         :type series_type: str
-        :rtype: :class:`stravalib.model.Stream`
+
+        :return: An dictionary of :class:`stravalib.model.Stream` from the effort.
+        :rtype: :py:class:`dict`
+
         """
 
         # stream are comma seperated list
         if types is not None:
-            types= ",".join(types)
+            types = ",".join(types)
 
         params = {}
         if resolution is not None:
@@ -933,24 +1118,24 @@ class Client(object):
         if series_type is not None:
             params["series_type"] = series_type
 
-        result_fetcher = functools.partial(
-                              self.protocol.get,
-                              '/segment_efforts/{id}/streams/{types}'.format(id=effort_id,
-                                                                        types=types),
-                                                           **params)
+        result_fetcher = functools.partial(self.protocol.get,
+                                           '/segment_efforts/{id}/streams/{types}'.format(id=effort_id, types=types),
+                                           **params)
 
         streams = BatchedResultsIterator(entity=model.Stream,
                                          bind_client=self,
                                          result_fetcher=result_fetcher)
 
         # Pack streams into dictionary
-        return {i.type : i for i in streams}
+        return {i.type: i for i in streams}
 
-    def get_segment_streams(self, segment_id, types=None,
-                            resolution=None, series_type=None):
+    def get_segment_streams(self, segment_id, types=None, resolution=None,
+                            series_type=None):
         """
         Returns an streams for a segment.
 
+        http://strava.github.io/api/v3/streams/#segment
+
         Streams represent the raw data of the uploaded file. External
         applications may only access this information for activities owned
         by the authenticated athlete.
@@ -965,24 +1150,29 @@ class Client(object):
         http://strava.github.io/api/v3/streams/#effort
 
         :param segment_id: The ID of segment.
-        :type: int
+        :type segment_id: int
+
         :param types: (optional) A list of the the types of streams to fetch.
         :type types: list
+
         :param resolution: (optional, default is 'all') indicates desired number
                             of data points. 'low' (100), 'medium' (1000),
                             'high' (10000) or 'all'.
         :type resolution: str
+
         :param series_type: (optional, default is 'distance'.  Relevant only if
                              using resolution either 'time' or 'distance'.
                              Used to index the streams if the stream is being
                              reduced.
         :type series_type: str
-        :rtype: :class:`stravalib.model.Stream`
+
+        :return: An dictionary of :class:`stravalib.model.Stream` from the effort.
+        :rtype: :py:class:`dict`
         """
 
         # stream are comma seperated list
         if types is not None:
-            types= ",".join(types)
+            types = ",".join(types)
 
         params = {}
         if resolution is not None:
@@ -991,19 +1181,16 @@ class Client(object):
         if series_type is not None:
             params["series_type"] = series_type
 
-        result_fetcher = functools.partial(
-                              self.protocol.get,
-                              '/segments/{id}/streams/{types}'.format(id=segment_id,
-                                                                        types=types),
-                                                            **params)
+        result_fetcher = functools.partial(self.protocol.get,
+                                           '/segments/{id}/streams/{types}'.format(id=segment_id, types=types),
+                                           **params)
 
         streams = BatchedResultsIterator(entity=model.Stream,
                                          bind_client=self,
                                          result_fetcher=result_fetcher)
 
         # Pack streams into dictionary
-        return {i.type : i for i in streams}
-
+        return {i.type: i for i in streams}
 
 
 class BatchedResultsIterator(object):
@@ -1031,7 +1218,7 @@ class BatchedResultsIterator(object):
         :type limit: int
 
         :param per_page: How many rows to fetch per page (default is 200).
-        :type per_page: int
+        :rtype: :py:class:`int`
         """
 
         self.log = logging.getLogger('{0.__module__}.{0.__name__}'.format(self.__class__))
@@ -1101,6 +1288,7 @@ class BatchedResultsIterator(object):
             self._counter += 1
             return result
 
+
 class ActivityUploader(object):
     """
     The "future" object that holds information about an activity file upload and can
@@ -1111,8 +1299,10 @@ class ActivityUploader(object):
         """
         :param client: The :class:`stravalib.client.Client` object that is handling the upload.
         :type client: :class:`stravalib.client.Client`
+
         :param response: The initial upload response.
-        :type response: dict
+        :type response: :py:class:`dict`
+
         """
         self.client = client
         self.update_from_repsonse(response)
@@ -1122,7 +1312,7 @@ class ActivityUploader(object):
         Updates internal state of object.
 
         :param response: The response object (dict).
-        :type response: dict
+        :type response: :py:class:`dict`
         :param raise_exc: Whether to raise an exception if the response
                           indicates an error state. (default True)
         :type raise_exc: bool
@@ -1175,11 +1365,14 @@ class ActivityUploader(object):
         :param timeout: The max seconds to wait. Will raise TimeoutExceeded
                         exception if this time passes without success or error response.
         :type timeout: float
+
         :param poll_interval: How long to wait between upload checks.  Strava
                               recommends 1s minimum. (default 1.0s)
         :type poll_interval: float
+
         :return: The uploaded Activity object (fetched from server)
         :rtype: :class:`stravalib.model.Activity`
+
         :raise stravalib.exc.TimeoutExceeded: If a timeout was specified and
                                               activity is still processing after
                                               timeout has elapsed.
